@@ -9,13 +9,6 @@ import warnings
 import math
 
 class HarrisHawkOptimization(BaseOptimizationAlgorithm):
-    """      
-        Attributes
-        ----------
-        best_feature_list : ndarray of shape (n_features)
-            list of features with the best result of the entire run
-
-    """
     def __init__(self,
                  objective_function,
                  n_iteration: int = 1000,
@@ -44,38 +37,15 @@ class HarrisHawkOptimization(BaseOptimizationAlgorithm):
 
         beta: float, default=0.5
             beta value for random levy walk
-
+            
+        Attributes
+        ----------
+        best_feature_list : ndarray of shape (n_features)
+            list of features with the best result of the entire run
         """
         super().__init__(objective_function, n_iteration, timeout, population_size, minimize)
         self.beta=beta
 
-    def _evaluate_fitness(self, model, x_train, y_train, x_valid, y_valid):
-        scores = []
-        for i, individual in enumerate(self.individuals):
-            chosen_features = [index for index in range(
-                x_train.shape[1]) if individual[index] == 1]
-            X_train_copy = x_train.iloc[:, chosen_features]
-            X_valid_copy = x_valid.iloc[:, chosen_features]
-            feature_hash = '_*_'.join(
-                sorted(self.feature_list[chosen_features]))
-            if feature_hash in self.feature_score_hash.keys():
-                score = self.feature_score_hash[feature_hash]
-            else:
-                score = self.objective_function(
-                    model, X_train_copy, y_train, X_valid_copy, y_valid)
-                if not(self.minimize):
-                    score = -score
-                self.feature_score_hash[feature_hash] = score
-            
-            if score < self.current_best_scores[i]:
-                self.current_best_scores[i] = score
-                self.current_best_individual_score_dimensions[i] = individual
-            if score < self.best_score:
-                self.best_score = score
-                self.best_dim = individual
-            scores.append(score)
-        return scores
-
     def _exploration_phase(self):
 
         q=np.random.random(len(self.exploration_individuals_indexes))
@@ -101,26 +71,11 @@ class HarrisHawkOptimization(BaseOptimizationAlgorithm):
         self.individuals[q_greater_indexes]=np.where(np.random.random(q_greater_individuals.shape)<X_update,1,0)
 
     def _temporary_evaluate_fitness(self, model, x_train, y_train, x_valid, y_valid,target_individuals):
-        scores = []
-        for i, individual in enumerate(target_individuals):
-            chosen_features = [index for index in range(
-                x_train.shape[1]) if individual[index] == 1]
-            x_train_copy = x_train.iloc[:, chosen_features]
-            x_valid_copy = x_valid.iloc[:, chosen_features]
-
-            feature_hash = '_*_'.join(
-                sorted(self.feature_list[chosen_features]))
-            if feature_hash in self.feature_score_hash.keys():
-                score = self.feature_score_hash[feature_hash]
-            else:
-                score = self.objective_function(
-                    model, x_train_copy, y_train, x_valid_copy, y_valid)
-                if not(self.minimize):
-                    score = -score
-                self.feature_score_hash[feature_hash] = score
-
-            scores.append(score)
-        return scores
+        _temp=self.individuals
+        self.individuals=target_individuals
+        res=super()._evaluate_fitness(model, x_train, y_train, x_valid, y_valid,0,0)
+        self.individuals=_temp
+        return res
 
     def _levy_walk(self,soft_besiege_with_dives_indexes):
         nume  = math.gamma(1 + self.beta) * np.sin(np.pi * self.beta / 2)
@@ -236,11 +191,6 @@ class HarrisHawkOptimization(BaseOptimizationAlgorithm):
 
         self.initialize_population(X_train)
 
-        self.current_best_individual_score_dimensions = self.individuals
-        self.current_best_scores = [np.inf]*self.population_size
-        self.gbest_individual = self.best_dim
-        self.v = np.zeros((self.population_size, X_train.shape[1]))
-
         if (self.timeout is not None):
             timeout_upper_limit = time.time() + self.timeout
         else:
@@ -285,4 +235,3 @@ class HarrisHawkOptimization(BaseOptimizationAlgorithm):
             self.best_feature_list = list(
                 self.feature_list[np.where(self.best_dim)[0]])
         return self.best_feature_list
-
