@@ -8,14 +8,6 @@ import scipy
 import warnings
 
 class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
-    """  
-    Attributes
-    ----------
-    best_feature_list : ndarray of shape (n_features)
-        list of features with the best result of the entire run
-
-    """
-
     def __init__(self,
                  objective_function,
                  n_iteration: int = 1000,
@@ -53,38 +45,19 @@ class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
 
         w: float, default=0.9
             Velocity weight factor
+
+        Attributes
+        ----------
+        best_feature_list : ndarray of shape (n_features)
+            list of features with the best result of the entire run
         """
         super().__init__(objective_function, n_iteration, timeout, population_size, minimize)
         self.c1 = c1
         self.c2 = c2
         self.w = w
 
-    def _evaluate_fitness(self, model, x_train, y_train, x_valid, y_valid):
-        scores = []
-        for i, individual in enumerate(self.individuals):
-            chosen_features = [index for index in range(
-                x_train.shape[1]) if individual[index] == 1]
-            X_train_copy = x_train.iloc[:, chosen_features]
-            X_valid_copy = x_valid.iloc[:, chosen_features]
-            feature_hash = '_*_'.join(
-                sorted(self.feature_list[chosen_features]))
-            if feature_hash in self.feature_score_hash.keys():
-                score = self.feature_score_hash[feature_hash]
-            else:
-                score = self.objective_function(
-                    model, X_train_copy, y_train, X_valid_copy, y_valid)
-                if not(self.minimize):
-                    score = -score
-                self.feature_score_hash[feature_hash] = score
-            
-            if score < self.current_best_scores[i]:
-                self.current_best_scores[i] = score
-                self.current_best_individual_score_dimensions[i] = individual
-            if score < self.best_score:
-                self.best_score = score
-                self.best_dim = individual
-            scores.append(score)
-        return scores
+    def _evaluate_fitness(self, model, x_train, y_train, x_valid, y_valid,particle_swarm_flag=0,dragon_fly_flag=0):
+        return super()._evaluate_fitness(model, x_train, y_train, x_valid, y_valid,particle_swarm_flag,dragon_fly_flag)
 
     def fit(self, model, X_train, y_train, X_valid, y_valid, verbose=True):
         """
@@ -141,7 +114,7 @@ class ParticleSwarmOptimization(BaseOptimizationAlgorithm):
             self._check_individuals()
 
             self.fitness_scores = self._evaluate_fitness(
-                model, X_train, y_train, X_valid, y_valid)
+                model, X_train, y_train, X_valid, y_valid,1,0)
 
             self.gbest_individual = self.best_dim
 
